/*

	ELEMENTAL_DLLSKRIT.H

	Team Elemental library header file to allow pseudo-execution of GPG functions in DSDLL's.

	Changes:
	- 06/09/02 : Canti, v0.1, initial test version
*/

#ifndef _ELEMENTAL_DLLSKRIT_H
#define _ELEMENTAL_DLLSKRIT_H


/*************************
** External Definitions **
*************************/

#define MAXBUFSIZE 65536 // maximum size for fixed-size buffers
#define MAXQUEUESIZE 100 // maximum number of commands queue-able at a time
#define MAXNUMSPAWN 100 // maximum number of game objects to which you can attach a message queue


/************************
** Function Prototypes **
************************/

/***************************************************************************************
**
** Name: QueueInit
**
** Desc: Initializes a new queue for a given container object
**
** unsigned int GoID - the GoID for the container object
**
***************************************************************************************/
void QueueInit(unsigned int GoID);

/***************************************************************************************
**
** Name: PushMessage
**
** Desc: Pushes a skrit command onto the message queue with the given GoID
**
** unsigned int GoID - the GoID for the container object
** char* msg - the message to process
**
***************************************************************************************/
void PushMessage(unsigned int GoID, char* msg);

/***************************************************************************************
**
** Name: PushMessage
**
** Desc: Pushes a skrit command onto the next available message queue, or if none is
**       available, whichever one it wants to :P
**
** char* msg - the message to process
**
***************************************************************************************/
void PushMessage(char* msg);

/***************************************************************************************
**
** Name: GetNextMessage
**
** Desc: Returns the next skrit command in the message queue
**
** unsigned int GoID - the GoID for the container object
**
***************************************************************************************/
const char* GetNextMessage(unsigned int GoID);

#endif // #ifndef _ELEMENTAL_DLLSKRIT_H
